@@ -1,6 +1,6 @@
 import os
 import numpy as np
-from atomai.core import atomstat
+from atomai import atomstat
 import pytest
 from numpy.testing import assert_allclose
 import matplotlib
@@ -43,8 +43,8 @@ def test_ica(imstack_):
     components, Xt, _ = imstack_.ica(4)
     assert_allclose(components, components_desired)
     assert_allclose(Xt, Xt_desired)
-  
-    
+
+
 def test_nmf(imstack_):
     test_nmf = np.load(test_nmf_, allow_pickle=True)
     components_desired, Xt_desired = test_nmf[0:2]
